@@ -12,7 +12,7 @@ import Data.ByteString (ByteString, empty)
 import Data.Conduit (Conduit)
 
 encode :: (Monad m) => Conduit ByteString m ByteString
-encode = U.encodeI B32H.b32h_encode_part B32H.b32h_encode_final empty
+encode = U.encodeI B32H.b32hEncodePart B32H.b32hEncodeFinal empty
 
 decode :: (Monad m, MonadThrow m) => Conduit ByteString m ByteString
-decode = U.decodeI B32H.b32h_decode_part B32H.b32h_decode_final empty
+decode = U.decodeI B32H.b32hDecodePart B32H.b32hDecodeFinal empty
